Index: /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/SPITZ12/MY_SRC/sbcblk.F90
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/SPITZ12/MY_SRC/sbcblk.F90	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/SPITZ12/MY_SRC/sbcblk.F90	(revision 9576)
@@ -45,5 +45,5 @@
    USE sbc_ice        ! Surface boundary condition: ice fields
    USE lib_fortran    ! to use key_nosignedzero
-#if defined key_lim3
+#if defined key_si3
    USE ice     , ONLY :   u_ice, v_ice, jpl, a_i_b, at_i_b, tm_su, rn_cnd_s
    USE icethd_dh      ! for CALL ice_thd_snwblow
@@ -65,5 +65,5 @@
    PUBLIC   sbc_blk_init  ! called in sbcmod
    PUBLIC   sbc_blk       ! called in sbcmod
-#if defined key_lim3
+#if defined key_si3
    PUBLIC   blk_ice_tau   ! routine called in iceforcing
    PUBLIC   blk_ice_flx   ! routine called in iceforcing
@@ -539,5 +539,5 @@
          &     * ( MIN( sf(jp_tair)%fnow(:,:,1), rt0_snow ) - rt0 ) * cpic * tmask(:,:,1)
       !
-#if defined key_lim3
+#if defined key_si3
       qns_oce(:,:) = zqlw(:,:) - zqsb(:,:) - zqla(:,:)                                ! non solar without emp (only needed by LIM3)
       qsr_oce(:,:) = qsr(:,:)
@@ -690,7 +690,7 @@
    END FUNCTION L_vap
 
-#if defined key_lim3
+#if defined key_si3
    !!----------------------------------------------------------------------
-   !!   'key_lim3'                                       ESIM sea-ice model
+   !!   'key_si3'                                       ESIM sea-ice model
    !!----------------------------------------------------------------------
    !!   blk_ice_tau : provide the air-ice stress
Index: /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/TEST_CASES/CANAL/MY_SRC/diawri.F90
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/TEST_CASES/CANAL/MY_SRC/diawri.F90	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/TEST_CASES/CANAL/MY_SRC/diawri.F90	(revision 9576)
@@ -51,5 +51,5 @@
    USE ioipsl         ! 
 
-#if defined key_lim3
+#if defined key_si3
    USE icewri 
 #endif
@@ -1076,5 +1076,5 @@
       ENDIF
 
-#if defined key_lim3
+#if defined key_si3
       IF( nn_ice == 2 ) THEN   ! condition needed in case agrif + ice-model but no-ice in child grid
          CALL ice_wri_state( kt, id_i, nh_i )
Index: /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/TEST_CASES/WAD/MY_SRC/bdyini.F90
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/TEST_CASES/WAD/MY_SRC/bdyini.F90	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/TEST_CASES/WAD/MY_SRC/bdyini.F90	(revision 9576)
@@ -344,5 +344,5 @@
         IF(lwp) WRITE(numout,*)
 
-#if defined key_lim3
+#if defined key_si3
         IF(lwp) WRITE(numout,*) 'Boundary conditions for sea ice:  '
         SELECT CASE( cn_ice_lim(ib_bdy) )                  
Index: /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/cfg.txt
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/cfg.txt	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/CONFIG/cfg.txt	(revision 9576)
@@ -15,2 +15,5 @@
 ORCA2_SAS_SI3_ST OCE_SRC ICE_SRC NST_SRC SAS_SRC
 ORCA2_SI3_OBS_ST OCE_SRC ICE_SRC
+AGRIF_NORDIC_ST OCE_SRC ICE_SRC NST_SRC
+AGRIF_NORDIC_NOAGRIF_ST OCE_SRC ICE_SRC NST_SRC
+SPITZ12_ST OCE_SRC ICE_SRC
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-ALTIX_NAUTILUS_MPT
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-ALTIX_NAUTILUS_MPT	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-ALTIX_NAUTILUS_MPT	(revision 9576)
@@ -84,7 +84,7 @@
 #  Run the parallel MPI executable 
 #
-  echo "Running time ${MPT_HOME}/bin/mpiexec_mpt -np " $OCEANCORES " ./opa"
+  echo "Running time ${MPT_HOME}/bin/mpiexec_mpt -np " $OCEANCORES " ./nemo"
 #
-  time ${MPT_HOME}/bin/mpiexec_mpt -np $OCEANCORES ./opa
+  time ${MPT_HOME}/bin/mpiexec_mpt -np $OCEANCORES ./nemo
 #
   post_test_tidyup
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-IBM_EKMAN_INGV
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-IBM_EKMAN_INGV	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-IBM_EKMAN_INGV	(revision 9576)
@@ -30,5 +30,5 @@
  export MP_SHARED_MEMORY=yes
  export MPIRUN="mpirun -n $OCEANCORES"
- export MPIRUN_MPMD="mpirun -np $OCEANCORES ./opa : -np $XIOS_NUMPROCS /home/delrosso/XIOS_1.0/xios-1.0/bin/xios_server.exe"
+ export MPIRUN_MPMD="mpirun -np $OCEANCORES ./nemo : -np $XIOS_NUMPROCS /home/delrosso/XIOS_1.0/xios-1.0/bin/xios_server.exe"
 
 #
@@ -69,15 +69,15 @@
 #  Run the parallel MPI executable 
 #
-#  echo "Running time ${MPIRUN} " $OCEANCORES " ./opa"
+#  echo "Running time ${MPIRUN} " $OCEANCORES " ./nemo"
 #
 
   if [ MPI_FLAG == "yes" ]; then
      if [ $XIOS_NUMPROCS -eq 0 ]; then
-       time ${MPIRUN} ./opa
+       time ${MPIRUN} ./nemo
      else
        time ${MPIRUN_MPMD}
      fi
   else
-       time ./opa
+       time ./nemo
   fi
 #
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-PW6_CALYPSO
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-PW6_CALYPSO	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-PW6_CALYPSO	(revision 9576)
@@ -65,11 +65,11 @@
 #  Run the parallel MPI executable 
 #
-#  echo "Running time ${MPIRUN} " $OCEANCORES " ./opa"
+#  echo "Running time ${MPIRUN} " $OCEANCORES " ./nemo"
 #
 
   if [ MPI_FLAG == "yes" ]; then
-     time ${MPIRUN} ./opa
+     time ${MPIRUN} ./nemo
   else
-     time ./opa
+     time ./nemo
   fi
 #
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-PW7_METO
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-PW7_METO	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-PW7_METO	(revision 9576)
@@ -71,13 +71,13 @@
   if [ MPI_FLAG == "yes" ]; then
      n=1
-     echo "./opa" > ./alltasks
+     echo "./nemo" > ./alltasks
      while [ $n -lt $OCEANCORES ]
      do
-       echo "./opa" >> ./alltasks
+       echo "./nemo" >> ./alltasks
        n=$(( $n + 1 ))
      done
      time ${MPIRUN} ./alltasks
   else
-     time ./opa
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-PW7_MONSOON
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-PW7_MONSOON	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-PW7_MONSOON	(revision 9576)
@@ -70,13 +70,13 @@
   if [ MPI_FLAG == "yes" ]; then
      n=1
-     echo "./opa" > ./alltasks
+     echo "./nemo" > ./alltasks
      while [ $n -lt $OCEANCORES ]
      do
-       echo "./opa" >> ./alltasks
+       echo "./nemo" >> ./alltasks
        n=$(( $n + 1 ))
      done
      time ${MPIRUN} ./alltasks
   else
-     time ./opa
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_ADA
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_ADA	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_ADA	(revision 9576)
@@ -63,12 +63,12 @@
 #  Run the parallel MPI executable 
 #
-#  echo "Running time ${MPIRUN} ./opa"
+#  echo "Running time ${MPIRUN} ./nemo"
 #
   if [ MPI_FLAG == "yes" ]; then
-     echo "Running time ${MPIRUN} ./opa -procs $OCEANCORES"
-     time ${MPIRUN} ./opa -procs $OCEANCORES
+     echo "Running time ${MPIRUN} ./nemo -procs $OCEANCORES"
+     time ${MPIRUN} ./nemo -procs $OCEANCORES
   else
-     echo "Running time ./opa"
-     time ./opa
+     echo "Running time ./nemo"
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_ADA_DEBUG
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_ADA_DEBUG	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_ADA_DEBUG	(revision 9576)
@@ -63,12 +63,12 @@
 #  Run the parallel MPI executable 
 #
-#  echo "Running time ${MPIRUN} ./opa"
+#  echo "Running time ${MPIRUN} ./nemo"
 #
   if [ MPI_FLAG == "yes" ]; then
-     echo "Running time ${MPIRUN} ./opa -procs $OCEANCORES"
-     time ${MPIRUN} ./opa -procs $OCEANCORES
+     echo "Running time ${MPIRUN} ./nemo -procs $OCEANCORES"
+     time ${MPIRUN} ./nemo -procs $OCEANCORES
   else
-     echo "Running time ./opa"
-     time ./opa
+     echo "Running time ./nemo"
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_ADA_O0
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_ADA_O0	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_ADA_O0	(revision 9576)
@@ -64,12 +64,12 @@
 #  Run the parallel MPI executable 
 #
-#  echo "Running time ${MPIRUN} ./opa"
+#  echo "Running time ${MPIRUN} ./nemo"
 #
   if [ MPI_FLAG == "yes" ]; then
-     echo "Running time ${MPIRUN} ./opa -procs $OCEANCORES"
-     time ${MPIRUN} ./opa  -procs $OCEANCORES
+     echo "Running time ${MPIRUN} ./nemo -procs $OCEANCORES"
+     time ${MPIRUN} ./nemo  -procs $OCEANCORES
   else
-     echo "Running time ./opa"
-     time ./opa
+     echo "Running time ./nemo"
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_CURIE
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_CURIE	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_CURIE	(revision 9576)
@@ -64,10 +64,10 @@
 #  Run the parallel MPI executable 
 #
-  echo "Running time ${MPIRUN} ./opa"
+  echo "Running time ${MPIRUN} ./nemo"
 #
   if [ MPI_FLAG == "yes" ]; then
-     time ${MPIRUN} ./opa
+     time ${MPIRUN} ./nemo
   else
-     time ./opa
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_MOBILIS
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_MOBILIS	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-X64_MOBILIS	(revision 9576)
@@ -62,8 +62,8 @@
        echo time `which mpirun` --report-bindings -x MALLOC_MMAP_MAX_=-1                 \
                                 -x MALLOC_TRIM_THRESHOLD_=33554432 -np $OCORES --bynode  \
-                                --mca mpi_paffinity_alone 1 ./opa 
+                                --mca mpi_paffinity_alone 1 ./nemo 
             time `which mpirun` --report-bindings -x MALLOC_MMAP_MAX_=-1                 \
                                 -x MALLOC_TRIM_THRESHOLD_=33554432 -np $OCORES --bynode  \
-                                --mca mpi_paffinity_alone 1 ./opa 
+                                --mca mpi_paffinity_alone 1 ./nemo 
   else
        if [ ! -f ./xios_server.exe ] && [ -f ${XIO_HOME}/bin/xios_server.exe ]; then
@@ -81,10 +81,10 @@
                                 -x MALLOC_TRIM_THRESHOLD_=33554432       \
                                 -np $XCORES ./xios_server.exe            \
-                              : -np $OCORES --bynode  --mca mpi_paffinity_alone 1 ./opa 
+                              : -np $OCORES --bynode  --mca mpi_paffinity_alone 1 ./nemo 
 #
             time `which mpirun` --report-bindings -x MALLOC_MMAP_MAX_=-1 \
                                 -x MALLOC_TRIM_THRESHOLD_=33554432       \
                                 -np $XCORES ./xios_server.exe            \
-                              : -np $OCORES --bynode  --mca mpi_paffinity_alone 1 ./opa 
+                              : -np $OCORES --bynode  --mca mpi_paffinity_alone 1 ./nemo 
 #
   fi
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-XC40_METO
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-XC40_METO	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-XC40_METO	(revision 9576)
@@ -71,6 +71,6 @@
         exit
      fi
-       echo time aprun -b -n $XCORES -N $X_PER_NODE ./xios_server.exe : -n $OCORES -N $O_PER_NODE ./opa
-            time aprun -b -n $XCORES -N $X_PER_NODE ./xios_server.exe : -n $OCORES -N $O_PER_NODE ./opa
+       echo time aprun -b -n $XCORES -N $X_PER_NODE ./xios_server.exe : -n $OCORES -N $O_PER_NODE ./nemo
+            time aprun -b -n $XCORES -N $X_PER_NODE ./xios_server.exe : -n $OCORES -N $O_PER_NODE ./nemo
 #
   else
@@ -78,6 +78,6 @@
 # Run SPMD case
 #
-    echo time aprun -b  -n $OCORES -N $O_PER_NODE ./opa
-         time aprun -b  -n $OCORES -N $O_PER_NODE ./opa
+    echo time aprun -b  -n $OCORES -N $O_PER_NODE ./nemo
+         time aprun -b  -n $OCORES -N $O_PER_NODE ./nemo
   fi
 #
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-XC_ARCHER_INTEL
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-XC_ARCHER_INTEL	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-XC_ARCHER_INTEL	(revision 9576)
@@ -71,6 +71,6 @@
 # Run SPMD case
 #
-       echo time aprun -b  -n $OCORES -N $O_PER_NODE ./opa
-            time aprun -b  -n $OCORES -N $O_PER_NODE ./opa
+       echo time aprun -b  -n $OCORES -N $O_PER_NODE ./nemo
+            time aprun -b  -n $OCORES -N $O_PER_NODE ./nemo
   else
        if [ ! -f ./xios_server.exe ] && [ -f ${XIO_HOME}/bin/xios_server.exe ]; then
@@ -85,6 +85,6 @@
 #  Run MPMD case
 #
-       echo time aprun -b -n $XCORES -N $X_PER_NODE ./xios_server.exe : -n $OCORES -N $O_PER_NODE ./opa
-            time aprun -b -n $XCORES -N $X_PER_NODE ./xios_server.exe : -n $OCORES -N $O_PER_NODE ./opa
+       echo time aprun -b -n $XCORES -N $X_PER_NODE ./xios_server.exe : -n $OCORES -N $O_PER_NODE ./nemo
+            time aprun -b -n $XCORES -N $X_PER_NODE ./xios_server.exe : -n $OCORES -N $O_PER_NODE ./nemo
 #
   fi
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-ifort_athena
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-ifort_athena	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-ifort_athena	(revision 9576)
@@ -65,11 +65,11 @@
 #  Run the parallel MPI executable 
 #
-#  echo "Running time ${MPIRUN} " $OCEANCORES " ./opa"
+#  echo "Running time ${MPIRUN} " $OCEANCORES " ./nemo"
 #
 
   if [ MPI_FLAG == "yes" ]; then
-     time ${MPIRUN} ./opa
+     time ${MPIRUN} ./nemo
   else
-     time ./opa
+     time ./nemo
   fi
 #
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-ifort_athena_xios
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-ifort_athena_xios	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-ifort_athena_xios	(revision 9576)
@@ -71,10 +71,10 @@
 #  Run the parallel MPI executable 
 #
-#  echo "Running time ${MPIRUN} " $OCEANCORES " ./opa"
+#  echo "Running time ${MPIRUN} " $OCEANCORES " ./nemo"
 #
 
   if [ MPI_FLAG == "yes" ]; then
      if [ $XIOS_NUMPROCS -eq 0 ]; then
-       time ${MPIRUN} ./opa
+       time ${MPIRUN} ./nemo
      else
 
@@ -85,5 +85,5 @@
        k=0
        while (( k < $OCEANCORES )) ; do
-          echo ./opa >> xioscmdfile
+          echo ./nemo >> xioscmdfile
           k=`expr $k + 1`
        done
@@ -97,5 +97,5 @@
      fi
   else
-     time ./opa
+     time ./nemo
   fi
 #
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-macport_osx
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-macport_osx	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-macport_osx	(revision 9576)
@@ -66,9 +66,9 @@
 #
   if [ MPI_FLAG == "yes" ]; then
-  echo "Running time ${MPIRUN} ./opa"
-     time ${MPIRUN} ./opa
+  echo "Running time ${MPIRUN} ./nemo"
+     time ${MPIRUN} ./nemo
   else
-  echo "Running time./opa"
-     time ./opa
+  echo "Running time./nemo"
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-macport_osx_debug
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-macport_osx_debug	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-macport_osx_debug	(revision 9576)
@@ -66,9 +66,9 @@
 #
   if [ MPI_FLAG == "yes" ]; then
-  echo "Running time ${MPIRUN} ./opa"
-     time ${MPIRUN} ./opa
+  echo "Running time ${MPIRUN} ./nemo"
+     time ${MPIRUN} ./nemo
   else
-  echo "Running time./opa"
-     time ./opa
+  echo "Running time./nemo"
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-mpmd-ALTIX_NAUTILUS_MPT
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-mpmd-ALTIX_NAUTILUS_MPT	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-mpmd-ALTIX_NAUTILUS_MPT	(revision 9576)
@@ -97,7 +97,7 @@
 #  Run the parallel MPI executable 
 #
-  echo "Running time ${MPT_HOME}/bin/mpiexec_mpt -np " $XIOCORES " ./xios_server.exe : -np " $OCEANCORES " ./opa"
+  echo "Running time ${MPT_HOME}/bin/mpiexec_mpt -np " $XIOCORES " ./xios_server.exe : -np " $OCEANCORES " ./nemo"
 #
-  time ${MPT_HOME}/bin/mpiexec_mpt -np $XIOCORES ./xios_server.exe :  -np $OCEANCORES ./opa
+  time ${MPT_HOME}/bin/mpiexec_mpt -np $XIOCORES ./xios_server.exe :  -np $OCEANCORES ./nemo
 #
   post_test_tidyup
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-openmpi_KARA_MERCATOR_XIOS
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-openmpi_KARA_MERCATOR_XIOS	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-openmpi_KARA_MERCATOR_XIOS	(revision 9576)
@@ -58,10 +58,10 @@
 #  Run the parallel MPI executable 
 #
-  echo "Running time ${MPIRUN} ./opa"
+  echo "Running time ${MPIRUN} ./nemo"
 #
   if [ MPI_FLAG == "yes" ]; then
-     mpirun -np $OCEANCORES ./opa
+     mpirun -np $OCEANCORES ./nemo
   else
-     time ./opa
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-openmpi_NAVITI_MERCATOR
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-openmpi_NAVITI_MERCATOR	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/batch-openmpi_NAVITI_MERCATOR	(revision 9576)
@@ -58,10 +58,10 @@
 #  Run the parallel MPI executable 
 #
-  echo "Running time ${MPIRUN} ./opa"
+  echo "Running time ${MPIRUN} ./nemo"
 #
   if [ MPI_FLAG == "yes" ]; then
-     mpirun -np $OCEANCORES ./opa
+     mpirun -np $OCEANCORES ./nemo
   else
-     time ./opa
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/sette_batch_template
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/sette_batch_template	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/BATCH_TEMPLATE/sette_batch_template	(revision 9576)
@@ -66,9 +66,9 @@
 #
   if [ MPI_FLAG == "yes" ]; then
-  echo "Running time ${MPIRUN} ./opa"
-     time ${MPIRUN} ./opa
+  echo "Running time ${MPIRUN} ./nemo"
+     time ${MPIRUN} ./nemo
   else
-  echo "Running time./opa"
-     time ./opa
+  echo "Running time./nemo"
+     time ./nemo
   fi
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/all_functions.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/all_functions.sh	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/all_functions.sh	(revision 9576)
@@ -412,6 +412,6 @@
 
 
-        [ -f ${EXE_DIR}/field_def_nemo-opa.xml ] || sed -i '/field_def_nemo-opa/d' $1
-        [ -f ${EXE_DIR}/field_def_nemo-lim.xml ] || sed -i '/field_def_nemo-lim/d' $1
+        [ -f ${EXE_DIR}/field_def_nemo-oce.xml ] || sed -i '/field_def_nemo-oce/d' $1
+        [ -f ${EXE_DIR}/field_def_nemo-ice.xml ] || sed -i '/field_def_nemo-ice/d' $1
         [ -f ${EXE_DIR}/field_def_nemo-pisces.xml ] || sed -i '/field_def_nemo-pisces/d' $1
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_AGRIF.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_AGRIF.cfg	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_AGRIF.cfg	(revision 9576)
@@ -1,2 +1,2 @@
-ORCA2_LIM_nemo_v3.7.tar ORCA2_LIM_nemo_v3.7
+ORCA2_ICE_nemo_v3.7.tar ORCA2_ICE_nemo_v3.7
 AGRIF_NORDIC_v4.0.tar AGRIF_NORDIC_v4.0
Index: anches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_LIM3_AGRIF.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_LIM3_AGRIF.cfg	(revision 9575)
+++ 	(revision )
@@ -1,1 +1,0 @@
-ORCA2_LIM_nemo_v3.7.tar ORCA2_LIM_nemo_v3.7
Index: anches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_LIM3_OBS.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_LIM3_OBS.cfg	(revision 9575)
+++ 	(revision )
@@ -1,1 +1,0 @@
-ORCA2_LIM_nemo_v3.7.tar ORCA2_LIM_nemo_v3.7
Index: anches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_LIM3_PISCES.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_LIM3_PISCES.cfg	(revision 9575)
+++ 	(revision )
@@ -1,1 +1,0 @@
-ORCA2_LIM_nemo_v3.7.tar  ORCA2_LIM_PISCES_v3.7
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_SI3_AGRIF.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_SI3_AGRIF.cfg	(revision 9576)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_SI3_AGRIF.cfg	(revision 9576)
@@ -0,0 +1,1 @@
+ORCA2_ICE_nemo_v3.7.tar ORCA2_ICE_nemo_v3.7
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_SI3_OBS.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_SI3_OBS.cfg	(revision 9576)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_SI3_OBS.cfg	(revision 9576)
@@ -0,0 +1,1 @@
+ORCA2_ICE_nemo_v3.7.tar ORCA2_ICE_nemo_v3.7
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_SI3_PISCES.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_SI3_PISCES.cfg	(revision 9576)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_ORCA2_SI3_PISCES.cfg	(revision 9576)
@@ -0,0 +1,1 @@
+ORCA2_ICE_nemo_v3.7.tar  ORCA2_ICE_PISCES_v3.7
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_SAS.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_SAS.cfg	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/input_SAS.cfg	(revision 9576)
@@ -1,2 +1,2 @@
-ORCA2_LIM_nemo_v3.7.tar ORCA2_LIM_nemo_v3.7
+ORCA2_ICE_nemo_v3.7.tar ORCA2_ICE_nemo_v3.7
 INPUTS_SAS_v3.5.tar SAS 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/iodef_sette.xml
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/iodef_sette.xml	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/iodef_sette.xml	(revision 9576)
@@ -12,6 +12,6 @@
 ============================================================================================================
     -->
-    <field_definition src="DEF_SHARED/field_def_nemo-opa.xml"/>
-    <field_definition src="DEF_SHARED/field_def_nemo-lim.xml"/>
+    <field_definition src="DEF_SHARED/field_def_nemo-oce.xml"/>
+    <field_definition src="DEF_SHARED/field_def_nemo-ice.xml"/>
     <field_definition src="DEF_SHARED/field_def_nemo-pisces.xml"/>
     <!-- 
@@ -165,6 +165,6 @@
 ============================================================================================================
     -->
-    <field_definition src="DEF_SHARED/field_def_nemo-opa.xml"/>
-    <field_definition src="DEF_SHARED/field_def_nemo-lim.xml"/>
+    <field_definition src="DEF_SHARED/field_def_nemo-oce.xml"/>
+    <field_definition src="DEF_SHARED/field_def_nemo-ice.xml"/>
     <field_definition src="DEF_SHARED/field_def_nemo-pisces.xml"/>
     <!-- 
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/param.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/param.cfg	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/param.cfg	(revision 9576)
@@ -1,4 +1,4 @@
 #- forcing files storing
-FORCING_DIR=~/FORCING
+FORCING_DIR=$WORKDIR/NEMO/FORC
 #- input files storing
 INPUT_DIR=${CONFIG_DIR}/${NEW_CONF}/EXP00
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/prepare_job.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/prepare_job.sh	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/prepare_job.sh	(revision 9576)
@@ -155,8 +155,8 @@
 # RUN OPA
 cd ${EXE_DIR}
-if [ ! -r ${EXE_DIR}/opa ]
+if [ ! -r ${EXE_DIR}/nemo ]
     then
-    echo "executable opa does not exist"
-    echo "executable opa does not exist, exit"  >> ${SETTE_DIR}/output.sette
+    echo "executable nemo does not exist"
+    echo "executable nemo does not exist, exit"  >> ${SETTE_DIR}/output.sette
     exit 1
 fi
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_beginner.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_beginner.sh	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_beginner.sh	(revision 9576)
@@ -41,5 +41,5 @@
 #
 #  makenemo  : to create successive exectuables in ${CONFIG_NAME}/BLD/bin/nemo.exe 
-#              and links to opa in ${CONFIG_NAME}/EXP00)
+#              and links to nemo in ${CONFIG_NAME}/EXP00)
 #
 #  param.cfg : sets and loads following directories:
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_chk_result.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_chk_result.sh	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_chk_result.sh	(revision 9576)
@@ -489,5 +489,5 @@
 # Restartability test
 #
- for restart_test in WGYREPIS_ST WORCA2LIM3PIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2AGR_ST
+ for restart_test in WGYREPIS_ST WORCA2SI3PIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2AGR_ST
  do
    resttest $NEMO_VALID $restart_test $pass
@@ -496,5 +496,5 @@
 # Reproducibility tests
 #
- for repro_test in WGYREPIS_ST WORCA2LIM3PIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2_LIM3_OBS_ST WORCA2AGR_ST
+ for repro_test in WGYREPIS_ST WORCA2SI3PIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2_SI3_OBS_ST WORCA2AGR_ST
  do
    reprotest $NEMO_VALID $repro_test $pass
@@ -516,5 +516,5 @@
    echo 'and'
    echo "$NEMO_VALID_REF at rev $NEMO_REV_REF"
-   for repro_test in WGYREPIS_ST WORCA2LIM3PIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2_LIM3_OBS_ST WORCA2AGR_ST
+   for repro_test in WGYREPIS_ST WORCA2SI3PIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2_SI3_OBS_ST WORCA2AGR_ST
    do
      runcmpres $NEMO_VALID $repro_test $NEMO_VALID_REF $NEMO_REV_REF $pass
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_rpt.SAS.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_rpt.SAS.sh	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_rpt.SAS.sh	(revision 9576)
@@ -302,5 +302,5 @@
 # Restartability test
 #
- for restart_test in WGYREPIS_LONG WORCA2LIM3PIS_LONG WORCA2OFFPIS_LONG WAMM12_LONG WISOMIP_LONG WORCA2AGUL_LONG
+ for restart_test in WGYREPIS_LONG WORCA2SI3PIS_LONG WORCA2OFFPIS_LONG WAMM12_LONG WISOMIP_LONG WORCA2AGUL_LONG
  do
    resttest $NEMO_VALID $restart_test $pass
@@ -309,5 +309,5 @@
 # Reproducibility tests
 #
- for repro_test in WGYREPIS_32 WORCA2LIM3PIS_32 WORCA2OFFPIS_32 WAMM12_32 WISOMIP_32 WORCA2_LIM3_OBS WORCA2AGUL_1_2 WORCA2AGUL_16 WORCA2AGUL_2_2_NAG
+ for repro_test in WGYREPIS_32 WORCA2SI3PIS_32 WORCA2OFFPIS_32 WAMM12_32 WISOMIP_32 WORCA2_SI3_OBS WORCA2AGUL_1_2 WORCA2AGUL_16 WORCA2AGUL_2_2_NAG
  do
    reprotest $NEMO_VALID $repro_test $pass
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_rpt.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_rpt.sh	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_rpt.sh	(revision 9576)
@@ -35,7 +35,7 @@
     cd ${TOOLS_DIR}/REBUILD_NEMO
     #SF echo "REBUILD LONG restart SAS files, without standard output"
-    ./rebuild_nemo -t 4 ../../CONFIG/ORCA2_SAS_LIM3_ST/LONG/SAS_00000240_restart_ice  $NPROC > /dev/null 2>&1
+    ./rebuild_nemo -t 4 ../../CONFIG/ORCA2_SAS_SI3_ST/LONG/SAS_00000240_restart_ice  $NPROC > /dev/null 2>&1
     #SF echo "REBUILD SHORT restart SAS files, without standard output"
-    ./rebuild_nemo -t 4 ../../CONFIG/ORCA2_SAS_LIM3_ST/SHORT/SAS_00000240_restart_ice $NPROC >&-
+    ./rebuild_nemo -t 4 ../../CONFIG/ORCA2_SAS_SI3_ST/SHORT/SAS_00000240_restart_ice $NPROC >&-
     cd ${SAS_RESTART_DIR}/LONG
     #SF echo "COPY rebuild restart files"
@@ -387,5 +387,5 @@
   COMPIL_DIR=${TOOLS_DIR}/COMPILE
   NPROC=32
-  SAS_RESTART_DIR=${CONFIG_DIR0}/ORCA2_SAS_LIM3_ST
+  SAS_RESTART_DIR=${CONFIG_DIR0}/ORCA2_SAS_SI3_ST
 #
 # Show current revision tag and branch name
@@ -417,5 +417,5 @@
 # Rebuild and restartability test for SAS
 # clem: not needed anymore
-# for restart_file in WORCA2_SAS_LIM3_ST
+# for restart_file in WORCA2_SAS_SI3_ST
 # do
 #   restfile $NEMO_VALID $restart_file $pass
@@ -425,5 +425,5 @@
  echo ""
  echo "   !----restart----!   "
- for restart_test in WGYRE_PISCES_ST WORCA2_LIM3_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_LIM3_ST WAGRIF_NORDIC_ST WSPITZ12_ST WISOMIP_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WWAD_ST WSAS_BIPER_ST 
+ for restart_test in WGYRE_PISCES_ST WORCA2_SI3_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_SI3_ST WAGRIF_NORDIC_ST WSPITZ12_ST WISOMIP_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WWAD_ST WSAS_BIPER_ST 
  do
    resttest $NEMO_VALID $restart_test $pass
@@ -433,5 +433,5 @@
  echo ""
  echo "   !----repro----!   "
- for repro_test in WGYRE_PISCES_ST WORCA2_LIM3_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_LIM3_ST WORCA2_LIM3_OBS_ST WAGRIF_NORDIC_ST WSPITZ12_ST WISOMIP_ST
+ for repro_test in WGYRE_PISCES_ST WORCA2_SI3_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_SI3_ST WORCA2_SI3_OBS_ST WAGRIF_NORDIC_ST WSPITZ12_ST WISOMIP_ST
  do
    reprotest $NEMO_VALID $repro_test $pass
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_test-cases.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_test-cases.sh	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_test-cases.sh	(revision 9576)
@@ -45,5 +45,5 @@
 #
 #  makenemo  : to create successive exectuables in ${CONFIG_NAME}/BLD/bin/nemo.exe 
-#              and links to opa in ${CONFIG_NAME}/EXP00)
+#              and links to nemo in ${CONFIG_NAME}/EXP00)
 #
 #  param.cfg : sets and loads following directories:
Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_xios.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_xios.sh	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_xios.sh	(revision 9576)
@@ -38,5 +38,5 @@
 #
 #  makenemo  : to create successive exectuables in ${CONFIG_NAME}/BLD/bin/nemo.exe 
-#              and links to opa in ${CONFIG_NAME}/EXP00)
+#              and links to nemo in ${CONFIG_NAME}/EXP00)
 #
 #  param.cfg : sets and loads following directories:

Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette.sh	(revision 9575)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette.sh	(revision 9576)
@@ -42,5 +42,5 @@
 #
 #  makenemo  : to create successive exectuables in ${CONFIG_NAME}/BLD/bin/nemo.exe 
-#              and links to opa in ${CONFIG_NAME}/EXP00)
+#              and links to nemo in ${CONFIG_NAME}/EXP00)
 #
 #  param.cfg : sets and loads following directories:
@@ -134,14 +134,15 @@
 # Description of configuration tested:
 # GYRE_PISCES       :  1 
-# ORCA2_LIM3_PISCES :  2 
+# ORCA2_SI3_PISCES  :  2 
 # ORCA2_OFF_PISCES  :  3 
 # AMM12             :  4 
 # SAS               :  5
-# ORCA2_LIM3_OBS    :  6
+# ORCA2_SI3_OBS     :  6
 # AGRIF             :  7 & 8  test AGRIF in a double zoom configuration (AGRIF_NORDIC)
 #                               and check that key_agrif without zoom = no key_agrif
 # SPITZ12           :  9      regional configuration including sea-ice and tides (Spitzbergen)
 
-for config in 1 2 3 4 5 6 7 8 9 
+#for config in 1 2 3 4 5 6 7 8 9
+for config in 9
 do
 
@@ -272,11 +273,11 @@
 
 # -----------------
-# ORCA2_LIM3_PISCES
+# ORCA2_SI3_PISCES
 # -----------------
 if [ ${config} -eq 2 ] ;  then
 ## Restartability tests for ORCA2_LIM3_PISCES
     export TEST_NAME="LONG"
     cd ${CONFIG_DIR0}
-    . ./makenemo -m ${CMP_NAM} -n ORCA2_LIM3_PISCES_ST -r ORCA2_LIM3_PISCES -j 8 del_key ${DEL_KEYS}
+    . ./makenemo -m ${CMP_NAM} -n ORCA2_SI3_PISCES_ST -r ORCA2_SI3_PISCES -j 8 del_key ${DEL_KEYS}
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -315,5 +316,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_LIM3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_SI3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     
     cd ${SETTE_DIR}
@@ -362,9 +363,9 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_LIM3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
-    cd ${SETTE_DIR}
-    . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
-
-## Reproducibility tests for ORCA2_LIM3_PISCES
+    . ./prepare_job.sh input_ORCA2_SI3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    cd ${SETTE_DIR}
+    . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
+
+## Reproducibility tests for ORCA2_SI3_PISCES
     export TEST_NAME="REPRO_4_8"
     cd ${CONFIG_DIR0}
@@ -403,5 +404,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_LIM3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_SI3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -440,5 +441,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_LIM3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_SI3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -729,5 +730,5 @@
     export TEST_NAME="LONG"
     cd ${CONFIG_DIR0}
-    . ./makenemo -m ${CMP_NAM} -n ORCA2_SAS_LIM3_ST -r ORCA2_SAS_LIM3 -j 8 del_key ${DEL_KEYS}
+    . ./makenemo -m ${CMP_NAM} -n ORCA2_SAS_SI3_ST -r ORCA2_SAS_SI3 -j 8 del_key ${DEL_KEYS}
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -839,5 +840,5 @@
 
 # --------------
-# ORCA2_LIM3_OBS
+# ORCA2_SI3_OBS
 # --------------
 ## Test assimilation interface code, OBS and ASM for reproducibility
@@ -847,5 +848,5 @@
     export TEST_NAME="REPRO_4_8"
     cd ${CONFIG_DIR0}
-    . ./makenemo -m ${CMP_NAM} -n ORCA2_LIM3_OBS_ST -r ORCA2_LIM3_PISCES -d "OPA_SRC LIM_SRC_3"  -j 8 add_key "key_asminc" del_key "key_top"
+    . ./makenemo -m ${CMP_NAM} -n ORCA2_SI3_OBS_ST -r ORCA2_SI3_PISCES -d "OCE_SRC ICE_SRC"  -j 8 add_key "key_asminc" del_key "key_top"
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -875,5 +876,5 @@
     set_namelist namelist_cfg ln_sshinc .true.
     set_namelist namelist_cfg ln_asmiau .true.
     #remove all useless options for pisces (due to ORCA2_LIM3_PISCES reference configuration)
     set_namelist namelist_top_cfg ln_trcdta .false. 
     # put ln_ironsed, ln_river, ln_ndepo, ln_dust to false
@@ -894,5 +895,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_LIM3_OBS.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_SI3_OBS.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -924,5 +925,5 @@
     set_namelist namelist_cfg ln_sshinc .true.
     set_namelist namelist_cfg ln_asmiau .true.
     #remove all useless options for pisces (due to ORCA2_LIM3_PISCES reference configuration)
     set_namelist namelist_top_cfg ln_trcdta .false.
     # put ln_ironsed, ln_river, ln_ndepo, ln_dust to false
@@ -943,5 +944,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_LIM3_OBS.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_SI3_OBS.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -272,11 +273,11 @@
 # -----------------
 if [ ${config} -eq 2 ] ;  then
-## Restartability tests for ORCA2_LIM3_PISCES
+## Restartability tests for ORCA2_SI3_PISCES
     export TEST_NAME="LONG"
     cd ${CONFIG_DIR0}
@@ -875,5 +876,5 @@
     set_namelist namelist_cfg ln_sshinc .true.
     set_namelist namelist_cfg ln_asmiau .true.
-    #remove all useless options for pisces (due to ORCA2_LIM3_PISCES reference configuration)
+    #remove all useless options for pisces (due to ORCA2_SI3_PISCES reference configuration)
     set_namelist namelist_top_cfg ln_trcdta .false. 
     # put ln_ironsed, ln_river, ln_ndepo, ln_dust to false
@@ -924,5 +925,5 @@
     set_namelist namelist_cfg ln_sshinc .true.
     set_namelist namelist_cfg ln_asmiau .true.
-    #remove all useless options for pisces (due to ORCA2_LIM3_PISCES reference configuration)
+    #remove all useless options for pisces (due to ORCA2_SI3_PISCES reference configuration)
     set_namelist namelist_top_cfg ln_trcdta .false.
     # put ln_ironsed, ln_river, ln_ndepo, ln_dust to false